@@ -8,6 +8,8 @@
 
 from __future__ import annotations
 
+import asyncio
+
 from typing import TYPE_CHECKING, Optional, cast
 
 import click
@@ -122,7 +124,17 @@ async def expose(
 )
 @click.option(
     "--centroid-method",
-    type=click.Choice(["nudge", "simple", "winpos", "sep", "zbplus", "zbminus"]),
+    type=click.Choice(
+        [
+            "nudge",
+            "simple",
+            "winpos",
+            "sep",
+            "zbplus",
+            "zbplus2",
+            "zbminus",
+        ]
+    ),
     help="The centroid method used to extract sources.",
 )
 @click.option(
@@ -151,7 +163,7 @@ async def loop(command: Command[JaegerActor], fps: FPS, **kwargs):
         **kwargs,
     )
 
-    if result is True:
+    if result is not False:
         return command.finish()
     else:
         return command.fail("The FVC loop failed.")
@@ -263,7 +275,45 @@ async def snapshot(command: JaegerCommandType, fps: FPS):
         no_write_summary=True,
     )
 
-    return command.finish() if result is True else command.fail()
+    if (
+        result is False
+        or result.fvc_transform is None
+        or result.fvc_transform.positionerTableMeas is None
+    ):
+        return command.fail("Failed getting FVC data.")
+
+    ptm = result.fvc_transform.positionerTableMeas
+    ptm = ptm.loc[:, ["positionerID", "alphaMeas", "betaMeas"]]
+    ptm.set_index("positionerID", inplace=True)
+
+    TOL = 5
+
+    positions = {}
+    highlight = []
+    for pid in ptm.index:
+        alpha = fps[pid].alpha
+        beta = fps[pid].beta
+        alpha_meas = ptm.loc[pid].alphaMeas
+        beta_meas = ptm.loc[pid].betaMeas
+        positions[pid] = {"alpha": alpha_meas, "beta": beta_meas}
+
+        if alpha is None or beta is None:
+            command.warning(f"Positioner {pid} position is unknown.")
+            highlight.append(pid)
+        elif abs(alpha_meas - alpha) > TOL or abs(beta_meas - beta) > TOL:
+            command.warning(
+                f"Positioner {pid} is off by more than {TOL} degrees! "
+                f"Measured position: ({alpha_meas:.2f}, {beta_meas:.2f})."
+            )
+            highlight.append(pid)
+
+    await fps.save_snapshot(
+        positions=positions,
+        highlight=highlight,
+        show_disabled=False,
+    )
+
+    return command.finish()
 
 
 async def take_fvc_loop(
@@ -359,6 +409,7 @@ async def take_fvc_loop(
                 plot=plot,
                 centroid_method=centroid_method,
                 use_new_invkin=use_invkin,
+                loop=asyncio.get_running_loop(),
             )
 
             # 3. Set current RMS and delta.
@@ -400,8 +451,8 @@ async def take_fvc_loop(
 
             # 6. Save processed file.
             proc_path = filename.with_name("proc-" + filename.name)
-            command.debug(f"Saving processed image {proc_path}")
-            await fvc.write_proc_image(proc_path)
+            command.debug(f"Asynchronously saving processed image {proc_path}")
+            asyncio.create_task(fvc.write_proc_image(proc_path, broadcast=True))
             proc_image_saved = True
 
             if reached is True:
@@ -429,14 +480,14 @@ async def take_fvc_loop(
                 and no_write_summary is False
                 and failed is False
             ):
-                command.info("Saving confSummaryF file.")
-                await fvc.write_summary_F()
+                command.info("Asynchronously saving confSummaryF file.")
+                asyncio.create_task(run_in_executor(fvc.write_summary_F, plot=False))
 
             if proc_image_saved is False:
                 if filename is not None and fvc.proc_hdu is not None:
                     proc_path = filename.with_name("proc-" + filename.name)
-                    command.debug(f"Saving processed image {proc_path}")
-                    await fvc.write_proc_image(proc_path)
+                    command.debug(f"Asynchronously saving processed image {proc_path}")
+                    asyncio.create_task(fvc.write_proc_image(proc_path, broadcast=True))
                 else:
                     command.warning("Cannot write processed image.")
         except Exception:
@@ -446,6 +497,6 @@ async def take_fvc_loop(
         await command.send_command("jaeger", "ieb fbi led1 led2 0")
 
     if reached is True or apply is False:
-        return True
+        return fvc
     else:
         return False
