@@ -26,7 +26,7 @@ from sdsstools import read_yaml_file
 
 from jaeger import config, log
 from jaeger.commands import Command, CommandID
-from jaeger.exceptions import FPSLockedError, JaegerUserWarning, TrajectoryError
+from jaeger.exceptions import JaegerUserWarning, TrajectoryError
 from jaeger.ieb import IEB
 from jaeger.maskbits import FPSStatus, ResponseCode
 from jaeger.utils import int_to_bytes
@@ -161,11 +161,6 @@ async def send_trajectory(
             f"Something went wrong sending the trajectory: {err}",
             err.trajectory,
         )
-    finally:
-        if traj.dump_file:
-            traj.dump_trajectory()
-            if command:
-                command.debug(trajectory_dump_file=traj.dump_file)
 
     msg = f"Trajectory sent in {traj.data_send_time:.1f} seconds."
     log.debug(msg)
@@ -177,6 +172,11 @@ async def send_trajectory(
         command.info(move_time=round(traj.move_time, 2))
 
     if start_trajectory is False:
+        if traj.dump_file:
+            traj.dump_trajectory()
+            if command:
+                command.debug(trajectory_dump_file=traj.dump_file)
+
         return traj
 
     msg = "Starting trajectory ..."
@@ -272,17 +272,6 @@ class Trajectory(object):
         self.fps = fps
         self.trajectories: TrajectoryDataType
 
-        if self.fps.locked:
-            raise FPSLockedError(
-                f"FPS is locked by {fps.locked_by}. Cannot send trajectories."
-            )
-
-        if self.fps.moving:
-            raise TrajectoryError(
-                "The FPS is moving. Cannot send new trajectory.",
-                self,
-            )
-
         if isinstance(trajectories, (str, pathlib.Path)):
             path = pathlib.Path(trajectories)
             if path.suffix == ".json":
@@ -390,18 +379,21 @@ class Trajectory(object):
     async def send(self):
         """Sends the trajectory but does not start it."""
 
+        if self.fps.locked:
+            raise TrajectoryError(f"FPS is locked by {self.fps.locked_by}.", self)
+
         self.move_time = 0.0
 
         await self.fps.stop_trajectory()
         await self.fps.stop_trajectory(clear_flags=True)
 
-        if not await self.fps.update_status(
-            positioner_ids=list(self.trajectories),
-            timeout=1.0,
-        ):
+        if not await self.fps.update_status(timeout=1.0):
             self.failed = True
             raise TrajectoryError("Some positioners did not respond.", self)
 
+        if self.fps.moving:
+            raise TrajectoryError("The FPS is moving. Cannot send trajectory.", self)
+
         # Check that all positioners are ready to receive a new trajectory.
         for pos_id in self.trajectories:
 
@@ -588,52 +580,7 @@ class Trajectory(object):
 
         self.start_time = time.time()
 
-        # min_trajectory_time = 5.0
-        # PS = PositionerStatus
-
         try:
-
-            # # The positioners take a bit to report that they are moving so if the
-            # # move time is too short, we don't try to check if the positioners started
-            # # moving (but we'll check later that they arrived to their positions.)
-            # if self.move_time >= min_trajectory_time:
-            #     await asyncio.sleep(min_trajectory_time)
-            #     await self.fps.update_status()
-
-            #     if self.fps.status & FPSStatus.IDLE:
-            #         raise TrajectoryError("Move failed to start.")
-
-            #     sbits = numpy.array([p.status for p in self.fps.values()])
-            #     not_moving = numpy.where(sbits & PS.DISPLACEMENT_COMPLETED)
-            #     if not_moving[0].any():
-            #         not_moving_pids = numpy.array(list(self.fps))[not_moving[0]]
-
-            #         # Before reporting that the positioner is not moving, check if
-            #         # it's already there.
-            #         await self.fps.update_position()
-            #         positions = self.fps.get_positions()
-
-            #         really_not_moving = []
-            #         for pid in not_moving_pids:
-            #             if pid not in self.trajectories:
-            #                 continue
-
-            #             current = positions[positions[:, 0] == pid][0, 1:]
-            #             alpha = self.trajectories[pid]["alpha"][-1][0]
-            #             beta = self.trajectories[pid]["beta"][-1][0]
-
-            #             if not numpy.allclose(current - [alpha, beta], 0, atol=0.1):
-            #                 really_not_moving.append(pid)
-
-            #         if len(really_not_moving) > 0:
-            #             not_moving_str = ", ".join(map(str, really_not_moving))
-            #             # Should this be an error?
-            #             warnings.warn(
-            #                 "Some positioners do not appear to be "
-            #                 f"moving: {not_moving_str}.",
-            #                 JaegerUserWarning,
-            #             )
-
             while True:
 
                 await asyncio.sleep(1)
@@ -692,8 +639,8 @@ class Trajectory(object):
 
         finally:
             # Not explicitely updating the positions here because save_snapshot()
-            # will do that and no need to waste extra time.
-            await self.fps.save_snapshot()
+            # will do that and no need to waste extra time. Do not wait for this.
+            asyncio.create_task(self.fps.save_snapshot())
 
             if self.dump_file:
                 self.dump_trajectory()
