@@ -155,9 +155,11 @@ class BaseFPS(Dict[int, Positioner], Generic[FPS_T]):
 
         if isinstance(positioner, self.positioner_class):
             positioner_id = positioner.positioner_id
-        else:
+        elif isinstance(positioner, int):
             positioner_id = positioner
             positioner = self.positioner_class(positioner_id, None, centre=centre)
+        else:
+            raise TypeError(f"Invalid parameter positioner of type {type(positioner)}")
 
         if positioner_id in self.positioners:
             raise JaegerError(
@@ -422,11 +424,14 @@ class FPS(BaseFPS["FPS"]):
             start_pollers = config["fps"]["start_pollers"]
         assert isinstance(start_pollers, bool)
 
-        self.disabled = set([])
         if keep_disabled:
             for positioner in self.positioners.values():
                 if positioner.offline or positioner.disabled:
                     self.disabled.add(positioner.positioner_id)
+                elif positioner.positioner_id in self.disabled:
+                    self.disabled.remove(positioner.positioner_id)
+        else:
+            self.disabled = set([])
 
         # Clear all robots
         self.clear()
@@ -601,49 +606,68 @@ class FPS(BaseFPS["FPS"]):
         # Disable collision detection for listed robots.
         disable_collision = config["fps"]["disable_collision_detection_positioners"]
         if len(disable_collision) > 0:
-            warnings.warn(
-                f"Disabling collision detection for positioners: {disable_collision}.",
-                JaegerUserWarning,
-            )
-            await self.send_command(
-                CommandID.ALPHA_CLOSED_LOOP_WITHOUT_COLLISION_DETECTION,
-                positioner_ids=disable_collision,
-            )
-            await self.send_command(
-                CommandID.BETA_CLOSED_LOOP_WITHOUT_COLLISION_DETECTION,
-                positioner_ids=disable_collision,
-            )
+            if self.locked:
+                warnings.warn(
+                    "The FPS is locked. Cannot disable collision detection",
+                    JaegerUserWarning,
+                )
+
+            else:
+                warnings.warn(
+                    "Disabling collision detection for positioners: "
+                    f"{disable_collision}.",
+                    JaegerUserWarning,
+                )
+                await self.send_command(
+                    CommandID.ALPHA_CLOSED_LOOP_WITHOUT_COLLISION_DETECTION,
+                    positioner_ids=disable_collision,
+                )
+                await self.send_command(
+                    CommandID.BETA_CLOSED_LOOP_WITHOUT_COLLISION_DETECTION,
+                    positioner_ids=disable_collision,
+                )
 
         # Set robots to open loop mode
         open_loop_positioners = config["fps"].get("open_loop_positioners", [])
         if len(open_loop_positioners) > 0:
-            warnings.warn(
-                f"Setting open loop mode for positioners: {open_loop_positioners}.",
-                JaegerUserWarning,
-            )
-            await self.send_command(
-                CommandID.ALPHA_OPEN_LOOP_WITHOUT_COLLISION_DETECTION,
-                positioner_ids=open_loop_positioners,
-            )
-            await self.send_command(
-                CommandID.BETA_OPEN_LOOP_WITHOUT_COLLISION_DETECTION,
-                positioner_ids=open_loop_positioners,
-            )
+            if self.locked:
+                warnings.warn(
+                    "The FPS is locked. Cannot set open loop mode.",
+                    JaegerUserWarning,
+                )
 
-        # Ensure closed loop mode for remaining robots
-        closed_loop_positioners = list(
-            set([pid for pid in self.positioners if not self[pid].disabled])
-            - set(disable_collision)
-            - set(open_loop_positioners)
-        )
-        await self.send_command(
-            CommandID.ALPHA_CLOSED_LOOP_COLLISION_DETECTION,
-            positioner_ids=closed_loop_positioners,
-        )
-        await self.send_command(
-            CommandID.BETA_CLOSED_LOOP_COLLISION_DETECTION,
-            positioner_ids=closed_loop_positioners,
-        )
+            else:
+                warnings.warn(
+                    "Setting open loop mode for positioners: "
+                    f"{open_loop_positioners}.",
+                    JaegerUserWarning,
+                )
+                await self.send_command(
+                    CommandID.ALPHA_OPEN_LOOP_WITHOUT_COLLISION_DETECTION,
+                    positioner_ids=open_loop_positioners,
+                )
+                await self.send_command(
+                    CommandID.BETA_OPEN_LOOP_WITHOUT_COLLISION_DETECTION,
+                    positioner_ids=open_loop_positioners,
+                )
+
+        # Ensure closed loop mode for remaining robots. This does not work if
+        # any of the robots is collided.
+        if not self.locked:
+
+            closed_loop_positioners = list(
+                set([pid for pid in self.positioners if not self[pid].disabled])
+                - set(disable_collision)
+                - set(open_loop_positioners)
+            )
+            await self.send_command(
+                CommandID.ALPHA_CLOSED_LOOP_COLLISION_DETECTION,
+                positioner_ids=closed_loop_positioners,
+            )
+            await self.send_command(
+                CommandID.BETA_CLOSED_LOOP_COLLISION_DETECTION,
+                positioner_ids=closed_loop_positioners,
+            )
 
         # Check that all the robots match the fibre assignments.
         self._check_fibre_assignments(raise_error=not skip_fibre_assignments_check)
@@ -987,7 +1011,8 @@ class FPS(BaseFPS["FPS"]):
     async def update_status(
         self,
         positioner_ids: Optional[int | List[int]] = None,
-        timeout: float = 1,
+        timeout: float = 2,
+        is_retry: bool = False,
     ) -> bool:
         """Update statuses for all positioners.
 
@@ -998,6 +1023,9 @@ class FPS(BaseFPS["FPS"]):
             positioners.
         timeout
             How long to wait before timing out the command.
+        is_retry
+            A flag to determine whether the function is being called
+            as a retry if the previous command timed out.
 
         """
 
@@ -1029,6 +1057,10 @@ class FPS(BaseFPS["FPS"]):
             log.warning(f"{CommandID.GET_STATUS.name!r} failed during update status.")
             return False
 
+        if command.status.timed_out and not is_retry:
+            log.warning("GET_STATUS timed out. Retrying.")
+            return await self.update_status(positioner_ids, is_retry=True)
+
         if len(command.replies) == 0:
             return True
 
@@ -1064,7 +1096,8 @@ class FPS(BaseFPS["FPS"]):
     async def update_position(
         self,
         positioner_ids: Optional[int | List[int]] = None,
-        timeout: float = 1,
+        timeout: float = 2,
+        is_retry: bool = False,
     ) -> numpy.ndarray | bool:
         """Updates positions.
 
@@ -1075,6 +1108,9 @@ class FPS(BaseFPS["FPS"]):
             initialised positioners.
         timeout
             How long to wait before timing out the command.
+        is_retry
+            A flag to determine whether the function is being called
+            as a retry if the previous command timed out.
 
         """
 
@@ -1100,6 +1136,10 @@ class FPS(BaseFPS["FPS"]):
             log.error(f"{command.name} failed during update position.")
             return False
 
+        if command.status.timed_out and not is_retry:
+            log.warning("GET_ACTUAL_POSITION timed out. Retrying.")
+            return await self.update_position(positioner_ids, is_retry=True)
+
         update_position_commands = []
         for pid, position in command.get_positions().items():  # type: ignore
             if pid not in self:
@@ -1115,6 +1155,7 @@ class FPS(BaseFPS["FPS"]):
         self,
         positioner_ids: Optional[int | List[int]] = None,
         timeout: float = 2,
+        is_retry: bool = False,
     ) -> bool:
         """Updates the firmware version of connected positioners.
 
@@ -1125,6 +1166,9 @@ class FPS(BaseFPS["FPS"]):
             positioners.
         timeout
             How long to wait before timing out the command.
+        is_retry
+            A flag to determine whether the function is being called
+            as a retry if the previous command timed out.
 
         """
 
@@ -1156,6 +1200,10 @@ class FPS(BaseFPS["FPS"]):
             log.error("Failed retrieving firmware version.")
             return False
 
+        if get_fw_command.status.timed_out and not is_retry:
+            log.warning("GET_FIRMWARE_VERSION timed out. Retrying.")
+            return await self.update_firmware_version(positioner_ids, is_retry=True)
+
         for reply in get_fw_command.replies:
             pid = reply.positioner_id
             if pid not in self.positioners:
@@ -1330,7 +1378,9 @@ class FPS(BaseFPS["FPS"]):
         self,
         path: Optional[str | pathlib.Path] = None,
         collision_buffer: float | None = None,
-        highlight: int | None = None,
+        positions: dict | None = None,
+        highlight: int | list | None = None,
+        show_disabled: bool = True,
         write_to_actor: bool = True,
     ) -> str | Axes:
         """Creates a plot with the current arrangement of the FPS array.
@@ -1342,8 +1392,16 @@ class FPS(BaseFPS["FPS"]):
             ``/data/logs/jaeger/snapshots/MJD/fps_snapshot_<SEQ>.pdf``.
         collision_buffer
             The collision buffer.
+        positions
+            A dictionary of positioner_id to a mapping of ``"alpha"`` and
+            ``"beta"`` positions (``{124: {"alpha": 223.4, "beta": 98.1}, ...}``).
+            If not provided, the internal FPS positions will be used.
         highlight
             A robot ID to highlight.
+        show_disabled
+            If `True`, greys out disabled positioners.
+        write_to_actor
+            If `True`, writes the name of the snapshot to the actor users.
 
         """
 
@@ -1370,8 +1428,10 @@ class FPS(BaseFPS["FPS"]):
 
         result = await get_snapshot(
             path,
+            positions=positions,
             collision_buffer=collision_buffer,
             highlight=highlight,
+            show_disabled=show_disabled,
         )
 
         if result is True and write_to_actor is True and jaeger.actor_instance:
